<?php
/**
 * @author Kyle Cunningham
 *
 * This file is copyright Kyle Cunningham and is licesned under the GNU GPL v2.
 * See LICENSE.txt for further licensing details.
 */

/**
 * @file
 * Default theme implementation for moderated comments.
 *
 * Available variables:
 * - $author: Comment author. Can be link or plain text.
 * - $content: Body of the post.
 * - $date: Date and time of posting.
 * - $links: Various operational links.
 * - $new: New comment marker.
 * - $picture: Authors picture.
 * - $signature: Authors signature.
 * - $status: Comment status. Possible values are:
 *   comment-unpublished, comment-published or comment-preview.
 * - $submitted: By line with date and time.
 * - $title: Linked title.
 * - $score: The score of the comment
 * - $promote_control: The link for promoting the comment.
 * - $bury_control: The link for burying the comment.
 *
 * These two variables are provided for context.
 * - $comment: Full comment object.
 * - $node: Node object the comments are attached to.
 *
 * @see template_preprocess_comment()
 * @see theme_comment()
 */
?>
<div id="<?php print $aname; ?>">
  <div class="comment-unfolded<?php print ($comment->new) ? ' comment-new' : ''; print ' ' . $status ?> clear-block">
    <?php print $picture ?>
   
    <?php if ($comment->new): ?>
      <span class="new"><?php print $new ?></span>
    <?php endif; ?>
   
    <span class="comment-unfolded-subject"><h3><?php print check_markup($title) ?> </h3></span>
   
    <div class="comment-unfolded-url-div">
      <span class="comment-unfolded-url"><?php print $url; ?></span>
    </div>
   
    <div class="comment-unfolded-score-div">
      <span class="comment-unfolded-score-label"><?php if (variable_get('comment_moderation_moderation_or_score', 0)) { 
        print $moderation_status;
      } else {
        print $score_label . ': '; 
      } ?></span>
      <?php if (!variable_get('comment_moderation_moderation_or_score', 0)): ?>
        <span class="comment-unfolded-score-value"><?php print $score; ?></span>
      <?php endif; ?>
    </div>
   
    <div class="comment-unfolded-voting-controls">
      <span class="comment-unfolded-promote"><?php print $promote_control; ?></span> <span class="comment-unfolded-bury"><?php print $bury_control ?></span>
    </div>
   
    <div class="comment-unfolded-submitted">
      <?php print check_markup($submitted) ?>
    </div>
   
    <div class="comment-unfolded-content">
      <?php print check_markup($content) ?>
      <?php if ($signature): ?>
      <div class="user-signature clear-block">
        <?php print check_markup($signature) ?>
      </div>
      <?php endif; ?>
    </div>
    <div class="comment-unfolded-links">
      <?php print $links ?>
    </div>
  </div>
</div>